@@ -287,8 +287,8 @@ class CustomerManagedPolicyReference(
         path: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param name: ``CfnPermissionSet.CustomerManagedPolicyReferenceProperty.Name``.
-        :param path: ``CfnPermissionSet.CustomerManagedPolicyReferenceProperty.Path``.
+        :param name: The name of the IAM policy that you have configured in each account where you want to deploy your permission set.
+        :param path: The path to the IAM policy that you have configured in each account where you want to deploy your permission set. The default is ``/`` . For more information, see `Friendly names and paths <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-friendly-names>`_ in the *IAM User Guide* .
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__d76e58f544c6bf87eb4ed6045f0b6948c3216099d824187a7cc57942e89eb9fe)
@@ -302,7 +302,7 @@ class CustomerManagedPolicyReference(
 
     @builtins.property
     def name(self) -> builtins.str:
-        '''``CfnPermissionSet.CustomerManagedPolicyReferenceProperty.Name``.
+        '''The name of the IAM policy that you have configured in each account where you want to deploy your permission set.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sso-permissionset-customermanagedpolicyreference.html#cfn-sso-permissionset-customermanagedpolicyreference-name
         '''
@@ -312,7 +312,9 @@ class CustomerManagedPolicyReference(
 
     @builtins.property
     def path(self) -> typing.Optional[builtins.str]:
-        '''``CfnPermissionSet.CustomerManagedPolicyReferenceProperty.Path``.
+        '''The path to the IAM policy that you have configured in each account where you want to deploy your permission set.
+
+        The default is ``/`` . For more information, see `Friendly names and paths <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-friendly-names>`_ in the *IAM User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sso-permissionset-customermanagedpolicyreference.html#cfn-sso-permissionset-customermanagedpolicyreference-path
         '''
@@ -471,8 +473,8 @@ class PermissionBoundary(
         managed_policy_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param customer_managed_policy_reference: ``CfnPermissionSet.PermissionsBoundaryProperty.CustomerManagedPolicyReference``.
-        :param managed_policy_arn: ``CfnPermissionSet.PermissionsBoundaryProperty.ManagedPolicyArn``.
+        :param customer_managed_policy_reference: Specifies the name and path of a customer managed policy. You must have an IAM policy that matches the name and path in each AWS account where you want to deploy your permission set.
+        :param managed_policy_arn: The AWS managed policy ARN that you want to attach to a permission set as a permissions boundary.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__4b19ce1fb3e89b904939ce873e787c40e49146fc1e9defc30a9c9e3df0a22c16)
@@ -488,7 +490,9 @@ class PermissionBoundary(
     def customer_managed_policy_reference(
         self,
     ) -> typing.Optional[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, _aws_cdk_ceddda9d.IResolvable]]:
-        '''``CfnPermissionSet.PermissionsBoundaryProperty.CustomerManagedPolicyReference``.
+        '''Specifies the name and path of a customer managed policy.
+
+        You must have an IAM policy that matches the name and path in each AWS account where you want to deploy your permission set.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sso-permissionset-permissionsboundary.html#cfn-sso-permissionset-permissionsboundary-customermanagedpolicyreference
         '''
@@ -497,7 +501,7 @@ class PermissionBoundary(
 
     @builtins.property
     def managed_policy_arn(self) -> typing.Optional[builtins.str]:
-        '''``CfnPermissionSet.PermissionsBoundaryProperty.ManagedPolicyArn``.
+        '''The AWS managed policy ARN that you want to attach to a permission set as a permissions boundary.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sso-permissionset-permissionsboundary.html#cfn-sso-permissionset-permissionsboundary-managedpolicyarn
         '''
